@@ -52,7 +52,7 @@ def _simulation_execute_operation(
         if current_status == "ERROR":
             error_message = simulation_dict["error_msg"]
             raise Exception(
-                "Error durring simulation operation: '{}'".format(error_message)
+                "Error during simulation operation: '{}'".format(error_message)
             )
         elif current_status != operation_status:
             # Operation has ended
@@ -150,7 +150,7 @@ def simu_create(architecture_file: str) -> int:
 #
 # 'simu_run' simulation
 #
-def simu_run(id_simulation: int, use_install_time: bool) -> None:
+def simu_run(id_simulation: int, use_install_time: bool = False) -> None:
     # Check that no other simulation is running
     simulation_list = core_api_client.fetch_simulations()
     for simulation in simulation_list:
