@@ -188,6 +188,9 @@ def provisioning_ansible_handler(args: Any) -> None:
     if provisioning_target_role is not None:
         raise NotImplementedError("target_role not yet supported")
 
+    if provisioning_target_name is None:
+        raise NotImplementedError("target_name (-n option) should be defined")
+
     try:
         provisioning_helper.provisioning_ansible(
             id_simulation,
